==> haskell-structured-0.1.1-173-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-structured.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 structured
version:              0.1.1
visibility:           public
id:                   structured-0.1.1-JeqTMil3PXPLQtzzpX0UMl
key:                  structured-0.1.1-JeqTMil3PXPLQtzzpX0UMl
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Structure (hash) of your data types
description:
    Calculate the hash of a data structure.
    It can be used as a magic number for the serialization formats.
    See <https://hackage.haskell.org/package/binary-tagged binary-tagged>
    for a @binary@ bindings.

category:             Data
abi:                  360084cceab31f63da511e2075480188
exposed:              True
exposed-modules:      Data.Structured Data.Structured.Internal
hidden-modules:       Data.Structured.MD5
import-dirs:          /usr/lib/ghc-9.2.8/site-local/structured-0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/structured-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-structured
hs-libraries:         HSstructured-0.1.1-JeqTMil3PXPLQtzzpX0UMl
depends:
    aeson-2.1.2.1-6EBV889cSS7AqjoZtYoje8 array-0.5.4.0 base-4.16.4.0
    base16-bytestring-1.0.2.0-9AKEfJpeJHOK2mzYhoV7G4 binary-0.8.9.0
    bytestring-0.11.4.0 containers-0.6.5.1
    hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    scientific-0.3.7.0-KUJ0yQBDqbB75MLhDe7uzc
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg text-1.2.5.0
    time-compat-1.9.6.1-4LKUUS0AewnA698ITHrhN1 transformers-0.5.6.2
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ
    uuid-types-1.0.5.1-DzR0IgzRElQ1K705w84ENs
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:   /usr/share/doc/haskell-structured/html/structured.haddock
haddock-html:         /usr/share/doc/haskell-structured/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-structured-0.1.1-182-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-structured.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 structured
version:              0.1.1
visibility:           public
id:                   structured-0.1.1-DTGcFHTqLB3D218ZoAoPZl
key:                  structured-0.1.1-DTGcFHTqLB3D218ZoAoPZl
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Structure (hash) of your data types
description:
    Calculate the hash of a data structure.
    It can be used as a magic number for the serialization formats.
    See <https://hackage.haskell.org/package/binary-tagged binary-tagged>
    for a @binary@ bindings.

category:             Data
abi:                  04a931dbc4699f3d231b790801e8d51d
exposed:              True
exposed-modules:      Data.Structured Data.Structured.Internal
hidden-modules:       Data.Structured.MD5
import-dirs:          /usr/lib/ghc-9.2.8/site-local/structured-0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/structured-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-structured
hs-libraries:         HSstructured-0.1.1-DTGcFHTqLB3D218ZoAoPZl
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr array-0.5.4.0 base-4.16.4.0
    base16-bytestring-1.0.2.0-1EKQKfIbtqrKykCu8OdSyV binary-0.8.9.0
    bytestring-0.11.4.0 containers-0.6.5.1
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    scientific-0.3.7.0-8x4tZ4xzXsRTNLFKkeuvD
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg text-1.2.5.0
    time-compat-1.9.6.1-Cd4ZO0rf1QSALzCGMKTb3h transformers-0.5.6.2
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu
    uuid-types-1.0.5.1-EtLF0k28bNc38E21nOo17r
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:   /usr/share/doc/haskell-structured/html/structured.haddock
haddock-html:         /usr/share/doc/haskell-structured/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
